pub enum PressedTo {
Voltage,
Ground,
}Expand description
Describes if the button connects to voltage or ground when pressed.
Variants
Voltage
Button connects pin to voltage (3.3V) when pressed. Uses internal pull-down resistor. Pin reads HIGH when pressed.
Ground
Button connects pin to ground (GND) when pressed. Uses internal pull-up resistor. Pin reads LOW when pressed.
Implementations
Sourceimpl PressedTo
impl PressedTo
Sourcepub const fn pressed_is_high(self) -> bool
pub const fn pressed_is_high(self) -> bool
Returns true when a high input level means “pressed”.
Sourcepub const fn is_pressed(self, level_is_high: bool) -> bool
pub const fn is_pressed(self, level_is_high: bool) -> bool
Evaluates whether the button is pressed for a sampled logic level.