#[non_exhaustive]pub enum Error {
CopySize {
src_len: usize,
frame_len: usize,
},
LcdI2cWrite {
address: u8,
},
LcdRowOutOfBounds {
row: usize,
},
CalibrationDegenerateGeometry,
CalibrationResidualTooLarge {
worst_residual_pixels: f32,
},
WifiAutoFormat,
WifiAutoStorageCorrupted,
WifiAutoMissingCustomField,
}Expand description
Unified error type for device-envoy-core.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
CopySize
A pixel copy’s source slice length did not match the destination frame length.
Fields
LcdI2cWrite
An I2C write to the character LCD’s expander failed for the given address.
LcdRowOutOfBounds
Attempted to set the character LCD cursor to an out-of-range row.
CalibrationDegenerateGeometry
Touch calibration input geometry was degenerate and could not be solved.
CalibrationResidualTooLarge
Touch calibration solved, but the residual error was too large to accept.
WifiAutoFormat
Captive-portal data or rendering format was invalid.
WifiAutoStorageCorrupted
Stored Wi-Fi auto state is invalid for expected runtime flow.
WifiAutoMissingCustomField
A required custom field is missing from the Wi-Fi auto setup.