pub struct ClockSyncWasm { /* private fields */ }Expand description
A ClockSync implementation backed by browser wall-clock time.
See the compiled crate::wasm::clock example.
Implementations
Sourceimpl ClockSyncWasm
impl ClockSyncWasm
Sourcepub fn new() -> Self
pub fn new() -> Self
Construct a clock using the browser’s current local UTC offset.
See the compiled crate::wasm::clock example.
Sourcepub fn show(&self)
pub fn show(&self)
Request the shared browser shell to display the time control.
See the compiled crate::wasm::clock example.
Sourcepub fn control_is_visible(&self) -> bool
pub fn control_is_visible(&self) -> bool
Return whether the shared browser shell should display the control.
See the compiled crate::wasm::clock example.