pub struct CydSimulatorWasm { /* private fields */ }Expand description
The reusable resources and input protocol for one browser CYD instance.
See the compiled crate::wasm::simulator example.
Implementations
Sourceimpl CydSimulatorWasm
impl CydSimulatorWasm
Sourcepub fn new(
canvas: HtmlCanvasElement,
orientation: Orientation,
) -> Result<Self, JsValue>
pub fn new( canvas: HtmlCanvasElement, orientation: Orientation, ) -> Result<Self, JsValue>
Construct a simulated CYD using the standard CYD browser palette.
See the compiled crate::wasm::simulator example.
Sourcepub fn new_with_style(
canvas: HtmlCanvasElement,
orientation: Orientation,
background_color: Rgb888,
foreground_color: Rgb888,
font: &'static MonoFont<'static>,
) -> Result<Self, JsValue>
pub fn new_with_style( canvas: HtmlCanvasElement, orientation: Orientation, background_color: Rgb888, foreground_color: Rgb888, font: &'static MonoFont<'static>, ) -> Result<Self, JsValue>
Construct a simulated CYD with an application-specific display style.
See the compiled crate::wasm::simulator example.
Sourcepub fn into_parts(self) -> (CydWasm, ButtonWasm, CydSimulatorControlWasm)
pub fn into_parts(self) -> (CydWasm, ButtonWasm, CydSimulatorControlWasm)
Split the simulator into application device resources and browser control.
See the compiled crate::wasm::simulator example.