Module memory

Module memory 

In-memory implementations for fast, deterministic native desktop tests.

Enable the host feature when testing in an ordinary Windows, macOS, or Linux process.

Implementations

Structs

ButtonMemory
Native desktop button test double returned by CydMemory::button_memory.
CydDisplayMemory
Owned display half of CydMemory.
CydFrameMemory
In-progress in-memory frame that flushes into an in-memory framebuffer.
CydMemory
In-memory CYD device for fast, deterministic native desktop tests and screenshots.
CydTouchMemory
Owned calibrated touch half of CydMemory.

Enums

Error
Error from the in-memory CYD test surface.

Functions

assert_framebuffer_matches_expected_png
Compare a rendered CydMemory framebuffer with an expected PNG.