pub struct Handle { /* private fields */ }Expand description
Stable browser control handle returned by start.
See the compiled browser-shell example on crate::wasm::cyd_web.
Implementations
Sourceimpl Handle
impl Handle
Sourcepub fn touch_down(&self, position_x: f32, position_y: f32)
pub fn touch_down(&self, position_x: f32, position_y: f32)
Press the simulated touch panel at canvas coordinates.
See the compiled browser-shell example on crate::wasm::cyd_web.
Sourcepub fn touch_move(&self, position_x: f32, position_y: f32)
pub fn touch_move(&self, position_x: f32, position_y: f32)
Move the simulated touch point.
See the compiled browser-shell example on crate::wasm::cyd_web.
Sourcepub fn touch_up(&self)
pub fn touch_up(&self)
Release the simulated touch panel.
See the compiled browser-shell example on crate::wasm::cyd_web.
Sourcepub fn boot_down(&self)
pub fn boot_down(&self)
Press the simulated BOOT button.
See the compiled browser-shell example on crate::wasm::cyd_web.
Sourcepub fn boot_up(&self)
pub fn boot_up(&self)
Release the simulated BOOT button.
See the compiled browser-shell example on crate::wasm::cyd_web.
Sourcepub fn orientation_is_inverted(&self) -> bool
pub fn orientation_is_inverted(&self) -> bool
Return whether the current orientation is inverted.
See the compiled browser-shell example on crate::wasm::cyd_web.
Sourcepub fn take_notice(&self) -> Option<Notice>
pub fn take_notice(&self) -> Option<Notice>
Remove and return the oldest pending framework notice.
See the compiled browser-shell example on crate::wasm::cyd_web.
Sourcepub fn request_restart(&self)
pub fn request_restart(&self)
Request an application restart.
See the compiled browser-shell example on crate::wasm::cyd_web.
Sourcepub fn clear_storage_and_restart(&self)
pub fn clear_storage_and_restart(&self)
Clear framework storage and restart the application.
See the compiled browser-shell example on crate::wasm::cyd_web.
Sourcepub fn clock_control_is_visible(&self) -> bool
pub fn clock_control_is_visible(&self) -> bool
Return whether the application has requested the clock control.
See the compiled browser-shell example on crate::wasm::cyd_web.
Sourcepub fn set_clock_time_of_day(&self, seconds_of_day: u32) -> Result<(), JsValue>
pub fn set_clock_time_of_day(&self, seconds_of_day: u32) -> Result<(), JsValue>
Set the simulated local time, in seconds after midnight.
See the compiled browser-shell example on crate::wasm::cyd_web.
Sourcepub fn use_live_clock(&self)
pub fn use_live_clock(&self)
Restore the browser’s live local clock.
See the compiled browser-shell example on crate::wasm::cyd_web.
Sourcepub fn page_title(&self) -> String
pub fn page_title(&self) -> String
Return the configured page title.
See the compiled browser-shell example on crate::wasm::cyd_web.
Sourcepub fn page_preview(&self) -> String
pub fn page_preview(&self) -> String
Return the configured preview text.
See the compiled browser-shell example on crate::wasm::cyd_web.
Sourcepub fn page_description(&self) -> String
pub fn page_description(&self) -> String
Return the configured page description.
See the compiled browser-shell example on crate::wasm::cyd_web.
Sourcepub fn page_controls(&self) -> String
pub fn page_controls(&self) -> String
Return the configured interaction instructions.
See the compiled browser-shell example on crate::wasm::cyd_web.
Sourcepub fn page_core_code_url(&self) -> String
pub fn page_core_code_url(&self) -> String
Return the configured platform-neutral source URL.
See the compiled browser-shell example on crate::wasm::cyd_web.